AshFormBuilder.NestedForm (AshFormBuilder v0.2.0)

Represents a nested relationship form declared via the nested DSL entity.

Stores its child Field structs in fields and the resolved destination resource (filled in by the transformer after reading Ash relationship metadata).